@@ -35,7 +35,7 @@ class RFXmlFormatter(FormatterBase):
         try:
             data = document.sourceText
             encoding = document.properties.get('encoding', "UTF-8") if document.properties else "UTF-8"
-            if document.sourceText and document.boundaries and document.annotations:
+            if document.sourceText and document.boundaries:
                 if data.lower().startswith("<?xml"):
                     decl, data = data.split("?>", maxsplit=1)
                     decl += "?>"
@@ -43,16 +43,17 @@ class RFXmlFormatter(FormatterBase):
                 baseNs = root.nsmap.get(None, None)
                 # Ignore all namespaces
                 for el in root.iter():
-                    if baseNs and el.tag.startswith(f"{{{baseNs}}}"):
+                    if baseNs and el.tag not in [ET.Comment, ET.PI, ET.Entity] and el.tag.startswith(f"{{{baseNs}}}"):
                         _, _, el.tag = el.tag.rpartition('}')
                 doc_annexes = root.find("DOC_ANNEXES")
                 if not doc_annexes:
                     doc_annexes = ET.Element("DOC_ANNEXES")
                     root.append(doc_annexes)
-                thesaurus = doc_annexes.find("ANNOTATIONS_SHERPA")
+                thesaurus: ET.Element = doc_annexes.find("ANNOTATIONS_THESAURUS")
                 if not thesaurus:
-                    thesaurus = ET.Element("ANNOTATIONS_SHERPA")
+                    thesaurus = ET.Element("ANNOTATIONS_THESAURUS")
                     doc_annexes.insert(0, thesaurus)
+                thesaurus.clear()
                 boundaries = {}
                 buckets = RangeBucketMap()
                 terms = defaultdict(lambda: defaultdict(list))
@@ -63,20 +64,21 @@ class RFXmlFormatter(FormatterBase):
                         node = r[0]
                         boundaries[node] = Range.closedOpen(boundary.start, boundary.end)
                         buckets[Range.closedOpen(boundary.start, boundary.end)] = node
-                for a in document.annotations:
-                    annotation = Annotation(**a) if isinstance(a, dict) else a
-                    form = document.text[annotation.start:annotation.end]
-                    if buckets.contains(annotation.start) and buckets.contains(annotation.end):
-                        zones = buckets[Range.closedOpen(annotation.start, annotation.end)]
-                        for zone in zones:
-                            for term in annotation.terms:
-                                ident = term.identifier if parameters.absolute_uri\
-                                    else term.identifier[term.identifier.index("#") + 1:]
-                                terms[zone][ident].append(form)
+                if document.annotations:
+                    for a in document.annotations:
+                        annotation = Annotation(**a) if isinstance(a, dict) else a
+                        form = document.text[annotation.start:annotation.end]
+                        if buckets.contains(annotation.start) and buckets.contains(annotation.end):
+                            zones = buckets[Range.closedOpen(annotation.start, annotation.end)]
+                            for zone in zones:
+                                for term in annotation.terms:
+                                    ident = term.identifier if parameters.absolute_uri\
+                                        else term.identifier[term.identifier.index("#") + 1:]
+                                    terms[zone][ident].append(form)
 
                 def left_longest_match(item):
                     r: Range = item[1]
-                    return r.lowerEndpoint(), r.upperEndpoint() - r.lowerEndpoint()
+                    return r.lowerEndpoint(), r.lowerEndpoint() - r.upperEndpoint()
 
                 sorted_boundaries = sorted(boundaries.items(), key=left_longest_match, reverse=False)
 
@@ -97,12 +99,14 @@ class RFXmlFormatter(FormatterBase):
                             descripteurs.append(descripteur)
                         thesaurus.append(descripteurs)
 
-                data = ET.tostring(root, pretty_print=True, encoding=encoding)
+                data = ET.tostring(root, pretty_print=True, encoding=encoding, xml_declaration=True)
             filename = "file.xml"
             if document.properties and "fileName" in document.properties:
                 filepath = Path(document.properties['fileName'])
                 filename = f"{filepath.stem}.xml"
-            resp = Response(content=data, media_type="application/xml")
+            media_type = "application/xml" if encoding.lower() == "utf-8" \
+                else f"application/xml; charset={encoding.lower()}"
+            resp = Response(content=data, media_type=media_type)
             resp.headers["Content-Disposition"] = f"attachment; filename={filename}"
             resp.charset = encoding
             return resp
